package aisl.ui;

import java.io.IOException;
import javax.servlet.RequestDispatcher;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

/**
 * Information about the next page to display.
 * <p> Handles both forwarding and redirection.
 */
public class DisplayInfo {

    private final String adresse;
    private boolean redirection = false;

    private DisplayInfo(String adresse, boolean redirection) {
        this.adresse = adresse;
        this.redirection = redirection;
    }

    /**
     * Crée une redirection.
     */
    public static DisplayInfo buildRedirection(String cheminRedirection) {
        return new DisplayInfo(cheminRedirection, true);
    }

     /**
     * Crée un affichage qui renvoie à une JSP dans WEB-INF/jsp.
     */
    public static DisplayInfo buildJsp(String nomJsp) {
        return new DisplayInfo(nomJsp, false);
    }

    public void display(HttpServlet servlet,
            HttpServletRequest request,
            HttpServletResponse response) throws IOException, ServletException {
        if (redirection) {
            response.sendRedirect(adresse);
        } else {
            String root= "/WEB-INF/jsp/";
            request.setAttribute("content",root + adresse);
            RequestDispatcher requestDispatcher =
                    servlet.getServletContext().getRequestDispatcher(root+"frame.jsp");
            requestDispatcher.forward(request, response);
        }
    }
}